# Поваренная книга

## Рецепты

- Мультитенантная маршрутизация
- Фоновые задания и повторные попытки
- Кэш + аннулирование
- Политика ограничения ставок
- Статические файлы с ETag/сжатием.
- Основы WebSocket
- основы шлюза gRPC
- Использование бегуна миграции

Каждый рецепт следует скопировать и адаптировать к вашим производственным ограничениям.